==> vod-api-model-1.0.0-sources.jar: com/valor/vod/api/model/meta/media/v1/TrailerDO.java <==
package com.valor.vod.api.model.meta.media.v1;

import com.valor.vod.api.model.common.I18nResDo;

/**
 * Project     : volor
 * Description : 附加视频（预告片，
 * Author      : Frank
 * Create Time : 2015/10/25 14:25
 */
public class TrailerDO extends I18nResDo {
    private long id;
    private TrailerType type;
    private String language;
    private String title;
    private String key;
    private String source;
    private int size;
    private String url;

    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }


    public String getLanguage() {
        return language;
    }

    public void setLanguage(String language) {
        this.language = language;
    }


    public String getKey() {
        return key;
    }

    public void setKey(String key) {
        this.key = key;
    }

    public void setKeyStr(String key) {
        this.key = key;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public TrailerType getType() {
        return type;
    }

    public void setType(TrailerType type) {
        this.type = type;
    }

    public void setType(String type) {
        this.type = TrailerType.fromString(type);
    }

    public void setTypeStr(String type) {
        this.type = TrailerType.fromString(type);
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public int getSize() {
        return size;
    }

    public void setSize(int size) {
        this.size = size;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }
}

==> vod-api-model-1.0.2-sources.jar: com/valor/vod/api/model/meta/media/v1/TrailerDO.java <==
package com.valor.vod.api.model.meta.media.v1;

import com.valor.vod.api.model.common.I18nResDo;

/**
 * 预告片
 *
 * @author Frank
 * @date 2015/10/25 14:25
 */
public class TrailerDO extends I18nResDo {
    private long id;
    private TrailerType type;
    private String language;
    private String title;
    private String key;
    private String source;
    private int size;
    private String url;

    public long getId() {
        return id;
    }

    public void setId(long id) {
        this.id = id;
    }

    public String getLanguage() {
        return language;
    }

    public void setLanguage(String language) {
        this.language = language;
    }

    public String getKey() {
        return key;
    }

    public void setKey(String key) {
        this.key = key;
    }

    public void setKeyStr(String key) {
        this.key = key;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public TrailerType getType() {
        return type;
    }

    public void setType(TrailerType type) {
        this.type = type;
    }

    public void setType(String type) {
        this.type = TrailerType.fromString(type);
    }

    public void setTypeStr(String type) {
        this.type = TrailerType.fromString(type);
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public int getSize() {
        return size;
    }

    public void setSize(int size) {
        this.size = size;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }
}
